Module ic_snapshot_coverage

Module ic_snapshot_coverage 

Incremental coverage of admitted snapshot replies, without IO or durable progress.

Structs

IcSnapshotDataCoverage
Ephemeral coverage of exact retained metadata by already decoded data replies.
IcSnapshotDataCoverageView
Read-only complete coverage of locally admitted replies, borrowing its owner.

Enums

IcSnapshotDataCoverageError
Typed coverage rejection without payloads, identifiers or raw decoder details.