pub enum RestoreSafetyObservationError {
InvalidTargetCount,
InvalidPrincipal,
DuplicateTarget,
TargetAbsentFromInventory,
}Expand description
Typed owning-boundary current evidence admission denial.
Variants
InvalidTargetCount
Actual rows must be nonempty and within the inventory bound.
InvalidPrincipal
Target principal failed bounded normalization.
DuplicateTarget
Canonical equivalent targets cannot appear twice.
TargetAbsentFromInventory
Actual row is absent from the actual full inventory.