checksum_file

Function checksum_file 

pub fn checksum_file(
    path: &Path,
) -> Result<ArtifactChecksumRecord, ArtifactError>
Checksum one regular filesystem file without following path symlinks.

Errors

Rejects unsafe entry types, unsupported platforms and filesystem failures.