pub fn checksum_path(
path: &Path,
) -> Result<ArtifactChecksumRecord, ArtifactError>Expand description
Checksum one file or a deterministic directory listing.
Errors
Rejects unsafe entry types, unsupported platforms and filesystem failures.
pub fn checksum_path(
path: &Path,
) -> Result<ArtifactChecksumRecord, ArtifactError>Checksum one file or a deterministic directory listing.
Rejects unsafe entry types, unsupported platforms and filesystem failures.