pub enum EffectGraphPersistenceError {
DigestMismatch,
Lock(JournalLockError),
Persistence(PersistenceError),
}Expand description
Typed declared graph identity or immutable local persistence rejection.
Variants
DigestMismatch
Retained graph differs from the original exact declared digest.
Lock(JournalLockError)
Cooperating layout/journal ownership failed.
Persistence(PersistenceError)
Bounded JSON, graph admission or durable filesystem access failed.