FenceObligationPersistenceError

Enum FenceObligationPersistenceError 

pub enum FenceObligationPersistenceError {
    DigestMismatch,
    Obligation(FenceObligationError),
    Plan(OperationPlanPersistenceError),
    Consistency(ConsistencyPersistenceError),
    Restore(RestoreSafetyPersistenceError),
    Lock(JournalLockError),
    Persistence(PersistenceError),
}
Typed denial preserving original obligation bytes and acquisition spending.

Variants



DigestMismatch

Retained obligation differs from the original exact expected digest.



Obligation(FenceObligationError)

Exact original fence scope or plan differs.



Plan(OperationPlanPersistenceError)

Original plan cannot be read under its unchanged layout.



Consistency(ConsistencyPersistenceError)

Exact original capture requirement cannot be read.



Restore(RestoreSafetyPersistenceError)

Exact original restore/source requirement cannot be read.



Lock(JournalLockError)

Journal exclusion failed.



Persistence(PersistenceError)

Bounded/durable filesystem or JSON operation failed.