pub enum IcSnapshotDataUploadPreparationError {
Planning(IcSnapshotDataUploadPlanningError),
Source(IcSnapshotUploadArtifactError),
}Expand description
Complete local plan preparation failure retains every original source record.
Variants
Planning(IcSnapshotDataUploadPlanningError)
Exact original workflow, allocation or finite plan admission failed.
Source(IcSnapshotUploadArtifactError)
Existing original guarded source/byte preparation failed.