pub fn checksum_file(
path: &Path,
) -> Result<ArtifactChecksumRecord, ArtifactError>Expand description
Checksum one regular filesystem file without following path symlinks.
Errors
Rejects unsafe entry types, unsupported platforms and filesystem failures.